/* Program Name            : IOPERF.H                                   */
/*   Original Author       : JLAURET                                    */
/*   Date                  : 23-Nov-1999                                */
/*   Program Description   : Restored IOPERF.H after losing it in major	*/
/*                         : RAID array crash.				*/

#include <sys/stat.h>
#include <time.h>

#if !defined(VAXC)
#include <sys/times.h>
#endif

#include <limits.h>
#include <math.h>

#ifdef VMS
#include <unixio.h>
#if !defined(VAXC)
#include <unistd.h>
#endif
#define UNLINK delete
#define SUCCESS 1
#define FAILURE 0
#define FORK vfork
#else
#define UNLINK unlink
#define SUCCESS 0
#define FAILURE 1
#define FORK fork
#endif

#ifndef MIN
#define MIN(a,b) (a>b?b:a)
#endif
#ifndef MAX
#define MAX(a,b) (a>b?a:b)
#endif


/* The above values have been checked with time shell built-int         */
/*~NoWarn*/
#if defined(VMS) && (__CRTL_VER < 70000000)
/*~PopWarn*/
  /* For lower version of CRTL, there was a major screw-up in run-time.
     First, the returned values obey some rules that only DEC knows the
     wisdom of that choice. Second, times() is called time(). Finally,
     the argument of time() has a different type than the standard
     function ... This has been corrected for RTL version greater than
     7. This being said.                                                */

# define SCALE          1.0
# define CLK_SCALE      100.0
# define TIMES  time
# define TypeT time_t
#else
  /* Returns in CPU clock units. Docs says that times() returns the
     number of ticks since last uptime i.e. real time can be extracted
     from it. "Return the elapsed real time, or (clock_t) -1 for errors.
     All times are in CLK_TCKths of a second."
     clock() is supposed to return a value in units of CLOCKS_PER_SEC This
     value is the amount of processor time used by the program i.e. that
     would do the cpu-time spent by the program ...
     Our variable
       TIMES    time3 time4     realtime        SCALE           CLK_TCK
       clock    time1 time2     cputime         CLK_SCALE       CLOCKS_PER_SEC
       */

# define SCALE          CLK_TCK
# define CLK_SCALE      CLOCKS_PER_SEC
# define TIMES times
# define TypeT struct tms
#endif


#define DIM             256     /* File length dimension        */
#define DFLT_BLOCK      512     /* Default Block size           */
#define DFLT_NUMIO      10000   /* Number of IO to perform      */
#define DFLT_NLOOP      1	/* Number of loops              */
#define DFLT_NSEEK	50	/* Max Number of Seek		*/


#define NTESTS		5		/* Number of Implemented tests	*/

#define PRCT		100.0		
#define BYTESCL		1024.0		/* KB=1024 Bytes		*/
#define BYTEST		"KB/sec"






/* There are 2 method for doing IO tests. The best is definitly		*/
/* fork().								*/
/* #define FORK_METHOD 1                                                */

#ifdef FORK_METHOD
# define BEGIN_TEST if ( (child = FORK()) == -1){ \
		      fprintf(stderr," fork() failed in test %d\n",test); \
		   } else if (child == 0){

# define END_TEST    exit(1); \
		   } if( wait(&child) == -1) fprintf(stderr,"Waiting %d ...",test)

# define RETURN(a)  exit(a)
#else
# define BEGIN_TEST  /* Nothing here to do				*/
# define END_TEST    /* Null Instruction will be used			*/
# define RETURN(a) return a
#endif


#define NEXTARG(a) a++;\
		   if (argc <= a){\
		     fprintf(stderr,"Missing arguments\n");\
		     return FAILURE;\
		   }\

